<TS version="2.1" language="la">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Crea novam inscriptionem</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Novus</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Copia inscriptionem iam selectam in latibulum systematis</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Transcribe</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">C&amp;laude</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Dele active selectam inscriptionem ex enumeratione</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Insere inscriptionem vel titulum ut quaeras</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exporta data in hac tabella in plicam</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Exporta</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Dele</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Hae sunt inscriptiones mittendi pensitationes.  Semper inspice quantitatem et inscriptionem accipiendi antequam nummos mittis.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Copia Inscriptionem</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Copia &amp;Titulum</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Muta</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Exporta Index Inscriptionum</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Inscriptio</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nullus titulus)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Dialogus Tesserae</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Insere tesseram</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nova tessera</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Itera novam tesseram</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Ostende tesseram</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Cifra cassidile</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Huic operationi necesse est tessera cassidili tuo ut cassidile reseret.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Resera cassidile</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Muta tesseram</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Confirma cifrationem cassidilis</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Monitio: Si cassidile tuum cifras et tesseram amittis, tu &lt;b&gt;AMITTES OMNES TUOS NUMMOS BITOS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Certusne es te velle tuum cassidile cifrare?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Cassidile cifratum</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">GRAVE: Oportet ulla prioria conservata quae fecisti de plica tui cassidilis reponi a nove generata cifrata plica cassidilis.  Propter securitatem, prioria conservata de plica non cifrata cassidilis inutilia fiet simul atque incipis uti novo cifrato cassidili.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Cassidile cifrare abortum est</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Cassidile cifrare abortum est propter internum errorem.  Tuum cassidile cifratum non est.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Tesserae datae non eaedem sunt.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Cassidile reserare abortum est.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Tessera inserta pro cassidilis decifrando prava erat.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Tessera cassidilis successa est in mutando.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Monitio: Litterae ut capitales seratae sunt!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Interdictum usque ad</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>unknown</source>
        <translation type="unfinished">ignotum</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Quantitas</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Summarium</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Monstra generale summarium cassidilis</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transactiones</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Inspicio historiam transactionum</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">E&amp;xi</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Exi applicatione</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;De %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Informatio de &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Monstra informationem de Qt</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Creare novum cassidilium</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Mitte nummos ad inscriptionem Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Conserva cassidile in locum alium</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Muta tesseram utam pro cassidilis cifrando</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Mitte</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Accipe</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Cifra claves privatas quae cassidili tui sunt</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Signa nuntios cum tuis inscriptionibus Bitcoin ut demonstres te eas possidere</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Verifica nuntios ut certus sis eos signatos esse cum specificatis inscriptionibus Bitcoin</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Plica</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Configuratio</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Auxilium</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Tabella instrumentorum "Tabs"</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">Optiones mandati initiantis</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 post</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Postremum acceptum frustum generatum est %1 abhinc.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transactiones post hoc nondum visibiles erunt.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Monitio</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informatio</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Recentissimo</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Fenestra</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Transactio missa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Transactio incipiens</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Cassidile &lt;b&gt;cifratum&lt;/b&gt; est et iam nunc &lt;b&gt;reseratum&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Cassidile &lt;b&gt;cifratum&lt;/b&gt; est et iam nunc &lt;b&gt;seratum&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Octecti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Quantitas:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Quantitas</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dies</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Confirmatum</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copia quantitatem</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Cassidile</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Muta Inscriptionem</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Titulus</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Inscriptio</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Nova inscriptio mittendi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Muta inscriptionem accipiendi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Muta inscriptionem mittendi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Inscriptio inserta "%1" non valida inscriptio Bitcoin est.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Non potuisse cassidile reserare</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Generare novam clavem abortum est.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versio</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Optiones mandati initiantis</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Schema</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Hora postremi frusti</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Glutina inscriptionem ex latibulo</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Optiones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Princeps</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Reconstitue omnes optiones clientis ad praedefinita.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Reconstitue Optiones</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Rete</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">Cassidile</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation type="unfinished">Aperi per se portam clientis Bitcoin in itineratore.  Hoc tantum effectivum est si itineratrum tuum supportat UPnP et id activum est.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation type="unfinished">Designa portam utendo &amp;UPnP</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">&amp;IP vicarii:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Porta:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Porta vicarii (e.g. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Fenestra</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">Monstra tantum iconem in tabella systematis postquam fenestram minifactam est.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation type="unfinished">&amp;Minifac in tabellam systematis potius quam applicationum</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation type="unfinished">M&amp;inifac ad claudendum</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;UI</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">&amp;Lingua monstranda utenti:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">&amp;Unita qua quantitates monstrare:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation type="unfinished">Selige praedefinitam unitam subdivisionis monstrare in interfacie et quando nummos mittere</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancella</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">praedefinitum</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">Confirma optionum reconstituere</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">Inscriptio vicarii tradita non valida est.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Schema</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">Monstrata informatio fortasse non recentissima est.  Tuum cassidile per se synchronizat cum rete Bitcoin postquam conexio constabilita est, sed hoc actio nondum perfecta est.</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">Immatura:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation type="unfinished">Fossum pendendum quod nondum maturum est</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation type="unfinished">Bitcoin incipere non potest: cliccare-ad-pensandum handler</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation type="unfinished">Tractatio URI</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Inscriptio</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Typus</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Rete</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation type="unfinished">Resultato URI nimis longo, conare minuere verba pro titulo / nuntio.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation type="unfinished">Error codificandi URI in codicem QR.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation type="unfinished">Salva codicem QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Versio clientis</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informatio</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation type="unfinished">Tempus initiandi</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Rete</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Numerus conexionum</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation type="unfinished">Catena frustorum</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Hora postremi frusti</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Aperi</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Terminale</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation type="unfinished">Debug catalogi plica</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Vacuefac terminale</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Ad</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Ab</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">Quantitas:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Titulus:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">Nuntius:</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Non potuisse cassidile reserare</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Quantitas:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Titulus:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Nuntius:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Copia Inscriptionem</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dies</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Titulus</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Nuntius</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Mitte Nummos</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">Inopia nummorum</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Octecti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Quantitas:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation type="unfinished">Transactionis merces:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Mitte pluribus accipientibus simul</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation type="unfinished">Adde &amp;Accipientem</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Pendendum:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Confirma actionem mittendi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Mitte</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copia quantitatem</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Transactionis merces</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation type="unfinished">Confirma mittendum nummorum</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation type="unfinished">Oportet quantitatem ad pensandum maiorem quam 0 esse.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation type="unfinished">Quantitas est ultra quod habes.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation type="unfinished">Quantitas est ultra quod habes cum merces transactionis %1 includitur.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nullus titulus)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Quantitas:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">Pensa &amp;Ad:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Titulus:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Nuntius:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation type="unfinished">Signationes - Signa / Verifica nuntium</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation type="unfinished">&amp;Signa Nuntium</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation type="unfinished">Insere hic nuntium quod vis signare</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Signatio</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation type="unfinished">Copia signationem in latibulum systematis</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation type="unfinished">Signa nuntium ut demonstres hanc inscriptionem Bitcoin a te possessa esse</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation type="unfinished">Signa &amp;Nuntium</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation type="unfinished">Reconstitue omnes campos signandi nuntii</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation type="unfinished">&amp;Verifica Nuntium</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation type="unfinished">Verifica nuntium ut cures signatum esse cum specifica inscriptione Bitcoin</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Verifica &amp;Nuntium</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation type="unfinished">Reconstitue omnes campos verificandi nuntii</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation type="unfinished">Clicca "Signa Nuntium" ut signatio generetur</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation type="unfinished">Inscriptio inserta non valida est.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation type="unfinished">Sodes inscriptionem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation type="unfinished">Inserta inscriptio clavem non refert.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation type="unfinished">Cassidilis reserare cancellatum est.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation type="unfinished">Clavis privata absens est pro inserta inscriptione.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation type="unfinished">Nuntium signare abortum est.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation type="unfinished">Nuntius signatus.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation type="unfinished">Signatio decodificari non potuit.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation type="unfinished">Sodes signationem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation type="unfinished">Signatio non convenit digesto nuntii</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation type="unfinished">Nuntium verificare abortum est.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation type="unfinished">Nuntius verificatus.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in at least one block, but less than 6 blocks.</extracomment>
        <translation type="unfinished">%1/non confirmata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in 6 or more blocks.</extracomment>
        <translation type="unfinished">%1 confirmationes</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dies</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished">Fons</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished">Generatum</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Ab</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">ignotum</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Ad</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">inscriptio propria</translation>
    </message>
    <message>
        <source>label</source>
        <translation type="unfinished">titulus</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation type="unfinished">Creditum</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation type="unfinished">non acceptum</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation type="unfinished">Debitum</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Transactionis merces</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation type="unfinished">Cuncta quantitas</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Nuntius</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished">Annotatio</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation type="unfinished">ID transactionis</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation type="unfinished">Informatio de debug</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation type="unfinished">Transactio</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation type="unfinished">Lectenda</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Quantitas</translation>
    </message>
    <message>
        <source>true</source>
        <translation type="unfinished">verum</translation>
    </message>
    <message>
        <source>false</source>
        <translation type="unfinished">falsum</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Haec tabula monstrat descriptionem verbosam transactionis</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Typus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Titulus</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation type="unfinished">Confirmatum (%1 confirmationes)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation type="unfinished">Generatum sed non acceptum</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Acceptum cum</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation type="unfinished">Acceptum ab</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Missum ad</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation type="unfinished">Pensitatio ad te ipsum</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Fossa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nullus titulus)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation type="unfinished">Status transactionis.  Supervola cum mure ut monstretur numerus confirmationum.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation type="unfinished">Dies et tempus quando transactio accepta est.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">Typus transactionis.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation type="unfinished">Quantitas remota ex pendendo aut addita ei.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Omne</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Hodie</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Hac hebdomade</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Hoc mense</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Postremo mense</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Hoc anno</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Acceptum cum</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Missum ad</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation type="unfinished">Ad te ipsum</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Fossa</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Alia</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Quantitas minima</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Confirmatum</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Typus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Inscriptio</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Intervallum:</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">ad</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Creare novum cassidilium</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Mitte Nummos</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Exporta</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exporta data in hac tabella in plicam</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Conserva cassidile</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation type="unfinished">Conservare abortum est.</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation type="unfinished">Successum in conservando</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation type="unfinished">Hoc est prae-dimittum experimentala aedes - utere eo periculo tuo proprio - nolite utere fodendo vel applicationibus mercatoriis</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation type="unfinished">Corruptum databasum frustorum invenitur</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation type="unfinished">Visne reficere databasum frustorum iam?</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Completo lengendi</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation type="unfinished">Error initiando databasem frustorum</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation type="unfinished">Error initiando systematem databasi cassidilis %s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation type="unfinished">Error legendo frustorum databasem</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation type="unfinished">Error aperiendo databasum frustorum</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation type="unfinished">Non potuisse auscultare in ulla porta.  Utere -listen=0 si hoc vis.</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Inopia nummorum</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation type="unfinished">Inopia descriptorum plicarum.</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Signandum transactionis abortum est</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">Magnitudo transactionis nimis parva</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Transactio nimis magna</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">Ignotum rete specificatum in -onlynet: '%s'</translation>
    </message>
    </context>
</TS>